package gov.anl.aps.dm.portal.controllers;

import gov.anl.aps.dm.portal.exceptions.DmPortalException;
import gov.anl.aps.dm.portal.exceptions.MissingProperty;
import gov.anl.aps.dm.portal.exceptions.ObjectAlreadyExists;
import gov.anl.aps.dm.portal.model.entities.PolicyType;
import gov.anl.aps.dm.portal.model.beans.PolicyTypeFacade;
import java.util.List;

import javax.ejb.EJB;
import javax.inject.Named;
import javax.enterprise.context.SessionScoped;
import org.apache.log4j.Logger;

@Named("policyTypeController")
@SessionScoped
public class PolicyTypeController extends CrudEntityController<PolicyType, PolicyTypeFacade>
{

    private static final Logger logger = Logger.getLogger(PolicyTypeController.class.getName());

    @EJB
    private PolicyTypeFacade policyTypeFacade;

    public PolicyTypeController() {
    }

    @Override
    protected PolicyTypeFacade getFacade() {
        return policyTypeFacade;
    }

    @Override
    protected PolicyType createEntityInstance() {
        return new PolicyType();
    }

    @Override
    public String getEntityTypeName() {
        return "policyType";
    }

    @Override
    public String getCurrentEntityInstanceName() {
        if (getCurrent() != null) {
            return getCurrent().getName();
        }
        return "";
    }

    @Override
    public List<PolicyType> getAvailableItems() {
        return super.getAvailableItems();
    }

    @Override
    public String prepareEdit(PolicyType policyType) {
        return super.prepareEdit(policyType);
    }

    @Override
    public void prepareEntityInsert(PolicyType policyType) throws ObjectAlreadyExists, MissingProperty {
        if ((policyType.getName() == null) || (policyType.getName().length() == 0)) {
            throw new MissingProperty("Name is missing.");
        }
        PolicyType existingPolicyType = policyTypeFacade.findByName(policyType.getName());
        if (existingPolicyType != null) {
            throw new ObjectAlreadyExists("Experiment type " + policyType.getName() + " already exists.");
        }
        logger.debug("Inserting new experiment type " + policyType.getName());
    }

    @Override
    public void prepareEntityUpdate(PolicyType policyType) throws DmPortalException {
        if ((policyType.getName() == null) || (policyType.getName().length() == 0)) {
            throw new MissingProperty("Name is missing.");
        }
    }
    
     @Override
     protected String getObjectAlreadyExistMessage(PolicyType policyType)  {
        if (policyType == null) {
            return null;
        }
        return "Experiment Policy " + policyType.getName() + " already exists."; 
    }
     
     public String prepareView() {
         return super.prepareView(current);
     }

    public boolean notSelected() {
        return current == null;
    }
    
}