package gov.anl.aps.dm.portal.controllers;

import gov.anl.aps.dm.portal.exceptions.DmPortalException;
import gov.anl.aps.dm.portal.exceptions.MissingProperty;
import gov.anl.aps.dm.portal.exceptions.ObjectAlreadyExists;
import gov.anl.aps.dm.portal.model.beans.RoleTypeFacade;
import gov.anl.aps.dm.portal.model.entities.RoleType;
import java.util.List;
import javax.ejb.EJB;
import javax.enterprise.context.SessionScoped;
import javax.inject.Named;
import org.apache.log4j.Logger;

@Named("roleTypeController")
@SessionScoped
public class RoleTypeController extends CrudEntityController<RoleType, RoleTypeFacade>
{
    private static final Logger logger = Logger.getLogger(RoleTypeController.class.getName());
    private final int rows = 25;

    @EJB
    private RoleTypeFacade roleTypeFacade;

    public RoleTypeController() {
    }
    
    public int getRows() {
        return rows;
    }
 
    @Override
    protected RoleTypeFacade getFacade() {
        return roleTypeFacade;
    }

    @Override
    protected RoleType createEntityInstance() {
        return new RoleType();
    }

    @Override
    public String getEntityTypeName() {
        return "roleType";
    }

    @Override
    public String getCurrentEntityInstanceName() {
        if (getCurrent() != null) {
            return getCurrent().getName();
        }
        return "";
    }

    @Override
    public List<RoleType> getAvailableItems() {
        return super.getAvailableItems();
    }

    @Override
    public String prepareEdit(RoleType roleType) {
        return super.prepareEdit(roleType);
    }

    @Override
    public void prepareEntityInsert(RoleType roleType) throws ObjectAlreadyExists, MissingProperty {
        if ((roleType.getName() == null) || (roleType.getName().length() == 0)) {
            throw new MissingProperty("Name is missing.");
        }
        RoleType existingRoleType = roleTypeFacade.findByName(roleType.getName());
        if (existingRoleType != null) {
            throw new ObjectAlreadyExists("Role Type " + roleType.getName() + " already exists.");
        }
        logger.debug("Inserting new roleType " + roleType.getName());
    }

    @Override
    public void prepareEntityUpdate(RoleType roleType) throws DmPortalException {
         if ((roleType.getName() == null) || (roleType.getName().length() == 0)) {
            throw new MissingProperty("Name is missing.");
        }
   }

     @Override
     protected String getObjectAlreadyExistMessage(RoleType roleType)  {
        if (roleType == null) {
            return null;
        }
        return "Role Type " + roleType.getName() + " already exists."; 
    }


    public boolean isRoleSystemType(RoleType roleType) {
        if (roleType == null) {
            logger.warn("Current row is not set");
            // Do nothing if current item is not set.
            return false;
        }

        return roleType.isIsSystemRole();
    }

    public boolean notSelected() {
        return current == null;
    }
    
}